==> pmml-model-gwt-1.6.0-sources.jar: org/dmg/pmml/gaussian_process/GaussianProcessModel.java <==

package org.dmg.pmml.gaussian_process;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.LocalTransformations;
import org.dmg.pmml.MathContext;
import org.dmg.pmml.MiningFunction;
import org.dmg.pmml.MiningSchema;
import org.dmg.pmml.Model;
import org.dmg.pmml.ModelExplanation;
import org.dmg.pmml.ModelStats;
import org.dmg.pmml.ModelVerification;
import org.dmg.pmml.Output;
import org.dmg.pmml.PMMLObject;
import org.dmg.pmml.Targets;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.nearest_neighbor.TrainingInstances;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "GaussianProcessModel", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "miningSchema",
    "output",
    "modelStats",
    "modelExplanation",
    "targets",
    "localTransformations",
    "radialBasisKernel",
    "ardSquaredExponentialKernel",
    "absoluteExponentialKernel",
    "generalizedExponentialKernel",
    "trainingInstances",
    "modelVerification"
})
@org.jpmml.model.annotations.Added((org.dmg.pmml.Version.PMML_4_3))
@JsonRootName("GaussianProcessModel")
@JsonPropertyOrder({
    "modelName",
    "miningFunction",
    "algorithmName",
    "optimizer",
    "scorable",
    "mathContext",
    "extensions",
    "miningSchema",
    "output",
    "modelStats",
    "modelExplanation",
    "targets",
    "localTransformations",
    "radialBasisKernel",
    "ardSquaredExponentialKernel",
    "absoluteExponentialKernel",
    "generalizedExponentialKernel",
    "trainingInstances",
    "modelVerification"
})
public class GaussianProcessModel
    extends Model
    implements HasExtensions<GaussianProcessModel>
{

    @XmlAttribute(name = "modelName")
    @JsonProperty("modelName")
    private String modelName;
    @XmlAttribute(name = "functionName", required = true)
    @JsonProperty("functionName")
    private MiningFunction miningFunction;
    @XmlAttribute(name = "algorithmName")
    @org.jpmml.model.annotations.Added((org.dmg.pmml.Version.PMML_4_4))
    @JsonProperty("algorithmName")
    private String algorithmName;
    @XmlAttribute(name = "optimizer")
    @JsonProperty("optimizer")
    private String optimizer;
    @XmlAttribute(name = "isScorable")
    @JsonProperty("isScorable")
    private Boolean scorable;
    @XmlAttribute(name = "x-mathContext")
    @org.jpmml.model.annotations.Added((org.dmg.pmml.Version.XPMML))
    @JsonProperty("x-mathContext")
    private MathContext mathContext;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "MiningSchema", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("MiningSchema")
    private MiningSchema miningSchema;
    @XmlElement(name = "Output", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Output")
    private Output output;
    @XmlElement(name = "ModelStats", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelStats")
    private ModelStats modelStats;
    @XmlElement(name = "ModelExplanation", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelExplanation")
    private ModelExplanation modelExplanation;
    @XmlElement(name = "Targets", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Targets")
    private Targets targets;
    @XmlElement(name = "LocalTransformations", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("LocalTransformations")
    private LocalTransformations localTransformations;
    @XmlElement(name = "RadialBasisKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("RadialBasisKernel")
    private RadialBasisKernel radialBasisKernel;
    @XmlElement(name = "ARDSquaredExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ARDSquaredExponentialKernel")
    private ARDSquaredExponentialKernel ardSquaredExponentialKernel;
    @XmlElement(name = "AbsoluteExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("AbsoluteExponentialKernel")
    private AbsoluteExponentialKernel absoluteExponentialKernel;
    @XmlElement(name = "GeneralizedExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("GeneralizedExponentialKernel")
    private GeneralizedExponentialKernel generalizedExponentialKernel;
    @XmlElement(name = "TrainingInstances", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("TrainingInstances")
    private TrainingInstances trainingInstances;
    @XmlElement(name = "ModelVerification", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelVerification")
    private ModelVerification modelVerification;
    private final static Boolean DEFAULT_SCORABLE = true;
    private final static long serialVersionUID = 67371269L;

    public GaussianProcessModel() {
    }

    @ValueConstructor
    public GaussianProcessModel(
        @org.jpmml.model.annotations.Property("miningFunction")
        MiningFunction miningFunction,
        @org.jpmml.model.annotations.Property("miningSchema")
        MiningSchema miningSchema,
        @org.jpmml.model.annotations.Property("radialBasisKernel")
        RadialBasisKernel radialBasisKernel,
        @org.jpmml.model.annotations.Property("ardSquaredExponentialKernel")
        ARDSquaredExponentialKernel ardSquaredExponentialKernel,
        @org.jpmml.model.annotations.Property("absoluteExponentialKernel")
        AbsoluteExponentialKernel absoluteExponentialKernel,
        @org.jpmml.model.annotations.Property("generalizedExponentialKernel")
        GeneralizedExponentialKernel generalizedExponentialKernel,
        @org.jpmml.model.annotations.Property("trainingInstances")
        TrainingInstances trainingInstances) {
        this.miningFunction = miningFunction;
        this.miningSchema = miningSchema;
        this.radialBasisKernel = radialBasisKernel;
        this.ardSquaredExponentialKernel = ardSquaredExponentialKernel;
        this.absoluteExponentialKernel = absoluteExponentialKernel;
        this.generalizedExponentialKernel = generalizedExponentialKernel;
        this.trainingInstances = trainingInstances;
    }

    @Override
    public String getModelName() {
        return modelName;
    }

    @Override
    public GaussianProcessModel setModelName(
        @org.jpmml.model.annotations.Property("modelName")
        String modelName) {
        this.modelName = modelName;
        return this;
    }

    @Override
    public MiningFunction getMiningFunction() {
        return miningFunction;
    }

    @Override
    public GaussianProcessModel setMiningFunction(
        @org.jpmml.model.annotations.Property("miningFunction")
        MiningFunction miningFunction) {
        this.miningFunction = miningFunction;
        return this;
    }

    @Override
    public String getAlgorithmName() {
        return algorithmName;
    }

    @Override
    public GaussianProcessModel setAlgorithmName(
        @org.jpmml.model.annotations.Property("algorithmName")
        String algorithmName) {
        this.algorithmName = algorithmName;
        return this;
    }

    public String getOptimizer() {
        return optimizer;
    }

    public GaussianProcessModel setOptimizer(
        @org.jpmml.model.annotations.Property("optimizer")
        String optimizer) {
        this.optimizer = optimizer;
        return this;
    }

    @Override
    public boolean isScorable() {
        if (scorable == null) {
            return DEFAULT_SCORABLE;
        } else {
            return scorable;
        }
    }

    @Override
    public GaussianProcessModel setScorable(
        @org.jpmml.model.annotations.Property("scorable")
        Boolean scorable) {
        this.scorable = scorable;
        return this;
    }

    @Override
    public MathContext getMathContext() {
        if (mathContext == null) {
            return MathContext.DOUBLE;
        } else {
            return mathContext;
        }
    }

    @Override
    public GaussianProcessModel setMathContext(
        @org.jpmml.model.annotations.Property("mathContext")
        MathContext mathContext) {
        this.mathContext = mathContext;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public GaussianProcessModel addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public MiningSchema getMiningSchema() {
        return miningSchema;
    }

    @Override
    public GaussianProcessModel setMiningSchema(
        @org.jpmml.model.annotations.Property("miningSchema")
        MiningSchema miningSchema) {
        this.miningSchema = miningSchema;
        return this;
    }

    @Override
    public Output getOutput() {
        return output;
    }

    @Override
    public GaussianProcessModel setOutput(
        @org.jpmml.model.annotations.Property("output")
        Output output) {
        this.output = output;
        return this;
    }

    @Override
    public ModelStats getModelStats() {
        return modelStats;
    }

    @Override
    public GaussianProcessModel setModelStats(
        @org.jpmml.model.annotations.Property("modelStats")
        ModelStats modelStats) {
        this.modelStats = modelStats;
        return this;
    }

    @Override
    public ModelExplanation getModelExplanation() {
        return modelExplanation;
    }

    @Override
    public GaussianProcessModel setModelExplanation(
        @org.jpmml.model.annotations.Property("modelExplanation")
        ModelExplanation modelExplanation) {
        this.modelExplanation = modelExplanation;
        return this;
    }

    @Override
    public Targets getTargets() {
        return targets;
    }

    @Override
    public GaussianProcessModel setTargets(
        @org.jpmml.model.annotations.Property("targets")
        Targets targets) {
        this.targets = targets;
        return this;
    }

    @Override
    public LocalTransformations getLocalTransformations() {
        return localTransformations;
    }

    @Override
    public GaussianProcessModel setLocalTransformations(
        @org.jpmml.model.annotations.Property("localTransformations")
        LocalTransformations localTransformations) {
        this.localTransformations = localTransformations;
        return this;
    }

    public RadialBasisKernel getRadialBasisKernel() {
        return radialBasisKernel;
    }

    public GaussianProcessModel setRadialBasisKernel(
        @org.jpmml.model.annotations.Property("radialBasisKernel")
        RadialBasisKernel radialBasisKernel) {
        this.radialBasisKernel = radialBasisKernel;
        return this;
    }

    public ARDSquaredExponentialKernel getARDSquaredExponentialKernel() {
        return ardSquaredExponentialKernel;
    }

    public GaussianProcessModel setARDSquaredExponentialKernel(
        @org.jpmml.model.annotations.Property("ardSquaredExponentialKernel")
        ARDSquaredExponentialKernel ardSquaredExponentialKernel) {
        this.ardSquaredExponentialKernel = ardSquaredExponentialKernel;
        return this;
    }

    public AbsoluteExponentialKernel getAbsoluteExponentialKernel() {
        return absoluteExponentialKernel;
    }

    public GaussianProcessModel setAbsoluteExponentialKernel(
        @org.jpmml.model.annotations.Property("absoluteExponentialKernel")
        AbsoluteExponentialKernel absoluteExponentialKernel) {
        this.absoluteExponentialKernel = absoluteExponentialKernel;
        return this;
    }

    public GeneralizedExponentialKernel getGeneralizedExponentialKernel() {
        return generalizedExponentialKernel;
    }

    public GaussianProcessModel setGeneralizedExponentialKernel(
        @org.jpmml.model.annotations.Property("generalizedExponentialKernel")
        GeneralizedExponentialKernel generalizedExponentialKernel) {
        this.generalizedExponentialKernel = generalizedExponentialKernel;
        return this;
    }

    public TrainingInstances getTrainingInstances() {
        return trainingInstances;
    }

    public GaussianProcessModel setTrainingInstances(
        @org.jpmml.model.annotations.Property("trainingInstances")
        TrainingInstances trainingInstances) {
        this.trainingInstances = trainingInstances;
        return this;
    }

    @Override
    public ModelVerification getModelVerification() {
        return modelVerification;
    }

    @Override
    public GaussianProcessModel setModelVerification(
        @org.jpmml.model.annotations.Property("modelVerification")
        ModelVerification modelVerification) {
        this.modelVerification = modelVerification;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = PMMLObject.traverse(visitor, getMiningSchema(), getOutput(), getModelStats(), getModelExplanation(), getTargets(), getLocalTransformations(), getRadialBasisKernel(), getARDSquaredExponentialKernel(), getAbsoluteExponentialKernel(), getGeneralizedExponentialKernel(), getTrainingInstances(), getModelVerification());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.5-sources.jar: org/dmg/pmml/gaussian_process/GaussianProcessModel.java <==

package org.dmg.pmml.gaussian_process;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.LocalTransformations;
import org.dmg.pmml.MathContext;
import org.dmg.pmml.MiningFunction;
import org.dmg.pmml.MiningSchema;
import org.dmg.pmml.Model;
import org.dmg.pmml.ModelExplanation;
import org.dmg.pmml.ModelStats;
import org.dmg.pmml.ModelVerification;
import org.dmg.pmml.Output;
import org.dmg.pmml.PMMLObject;
import org.dmg.pmml.Targets;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.nearest_neighbor.TrainingInstances;
import org.jpmml.model.MissingAttributeException;
import org.jpmml.model.MissingElementException;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "GaussianProcessModel", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "miningSchema",
    "output",
    "modelStats",
    "modelExplanation",
    "targets",
    "localTransformations",
    "radialBasisKernel",
    "ardSquaredExponentialKernel",
    "absoluteExponentialKernel",
    "generalizedExponentialKernel",
    "trainingInstances",
    "modelVerification"
})
@org.jpmml.model.annotations.Added((org.dmg.pmml.Version.PMML_4_3))
@JsonRootName("GaussianProcessModel")
@JsonPropertyOrder({
    "modelName",
    "miningFunction",
    "algorithmName",
    "optimizer",
    "scorable",
    "mathContext",
    "extensions",
    "miningSchema",
    "output",
    "modelStats",
    "modelExplanation",
    "targets",
    "localTransformations",
    "radialBasisKernel",
    "ardSquaredExponentialKernel",
    "absoluteExponentialKernel",
    "generalizedExponentialKernel",
    "trainingInstances",
    "modelVerification"
})
public class GaussianProcessModel
    extends Model
    implements HasExtensions<GaussianProcessModel>
{

    @XmlAttribute(name = "modelName")
    @JsonProperty("modelName")
    private String modelName;
    @XmlAttribute(name = "functionName", required = true)
    @JsonProperty("functionName")
    private MiningFunction miningFunction;
    @XmlAttribute(name = "algorithmName")
    @org.jpmml.model.annotations.Added((org.dmg.pmml.Version.PMML_4_4))
    @JsonProperty("algorithmName")
    private String algorithmName;
    @XmlAttribute(name = "optimizer")
    @JsonProperty("optimizer")
    private String optimizer;
    @XmlAttribute(name = "isScorable")
    @JsonProperty("isScorable")
    private Boolean scorable;
    @XmlAttribute(name = "x-mathContext")
    @org.jpmml.model.annotations.Added((org.dmg.pmml.Version.XPMML))
    @JsonProperty("x-mathContext")
    private MathContext mathContext;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "MiningSchema", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("MiningSchema")
    private MiningSchema miningSchema;
    @XmlElement(name = "Output", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Output")
    private Output output;
    @XmlElement(name = "ModelStats", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelStats")
    private ModelStats modelStats;
    @XmlElement(name = "ModelExplanation", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelExplanation")
    private ModelExplanation modelExplanation;
    @XmlElement(name = "Targets", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Targets")
    private Targets targets;
    @XmlElement(name = "LocalTransformations", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("LocalTransformations")
    private LocalTransformations localTransformations;
    @XmlElement(name = "RadialBasisKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("RadialBasisKernel")
    private RadialBasisKernel radialBasisKernel;
    @XmlElement(name = "ARDSquaredExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ARDSquaredExponentialKernel")
    private ARDSquaredExponentialKernel ardSquaredExponentialKernel;
    @XmlElement(name = "AbsoluteExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("AbsoluteExponentialKernel")
    private AbsoluteExponentialKernel absoluteExponentialKernel;
    @XmlElement(name = "GeneralizedExponentialKernel", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("GeneralizedExponentialKernel")
    private GeneralizedExponentialKernel generalizedExponentialKernel;
    @XmlElement(name = "TrainingInstances", namespace = "http://www.dmg.org/PMML-4_4", required = true)
    @JsonProperty("TrainingInstances")
    private TrainingInstances trainingInstances;
    @XmlElement(name = "ModelVerification", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("ModelVerification")
    private ModelVerification modelVerification;
    private final static Boolean DEFAULT_SCORABLE = true;
    private final static long serialVersionUID = 67371270L;

    public GaussianProcessModel() {
    }

    @ValueConstructor
    public GaussianProcessModel(
        @org.jpmml.model.annotations.Property("miningFunction")
        MiningFunction miningFunction,
        @org.jpmml.model.annotations.Property("miningSchema")
        MiningSchema miningSchema,
        @org.jpmml.model.annotations.Property("radialBasisKernel")
        RadialBasisKernel radialBasisKernel,
        @org.jpmml.model.annotations.Property("ardSquaredExponentialKernel")
        ARDSquaredExponentialKernel ardSquaredExponentialKernel,
        @org.jpmml.model.annotations.Property("absoluteExponentialKernel")
        AbsoluteExponentialKernel absoluteExponentialKernel,
        @org.jpmml.model.annotations.Property("generalizedExponentialKernel")
        GeneralizedExponentialKernel generalizedExponentialKernel,
        @org.jpmml.model.annotations.Property("trainingInstances")
        TrainingInstances trainingInstances) {
        this.miningFunction = miningFunction;
        this.miningSchema = miningSchema;
        this.radialBasisKernel = radialBasisKernel;
        this.ardSquaredExponentialKernel = ardSquaredExponentialKernel;
        this.absoluteExponentialKernel = absoluteExponentialKernel;
        this.generalizedExponentialKernel = generalizedExponentialKernel;
        this.trainingInstances = trainingInstances;
    }

    @Override
    public String getModelName() {
        return modelName;
    }

    @Override
    public GaussianProcessModel setModelName(
        @org.jpmml.model.annotations.Property("modelName")
        String modelName) {
        this.modelName = modelName;
        return this;
    }

    @Override
    public MiningFunction requireMiningFunction() {
        if (this.miningFunction == null) {
            throw new MissingAttributeException(this, PMMLAttributes.GAUSSIANPROCESSMODEL_MININGFUNCTION);
        }
        return this.miningFunction;
    }

    @Override
    public MiningFunction getMiningFunction() {
        return miningFunction;
    }

    @Override
    public GaussianProcessModel setMiningFunction(
        @org.jpmml.model.annotations.Property("miningFunction")
        MiningFunction miningFunction) {
        this.miningFunction = miningFunction;
        return this;
    }

    @Override
    public String getAlgorithmName() {
        return algorithmName;
    }

    @Override
    public GaussianProcessModel setAlgorithmName(
        @org.jpmml.model.annotations.Property("algorithmName")
        String algorithmName) {
        this.algorithmName = algorithmName;
        return this;
    }

    public String getOptimizer() {
        return optimizer;
    }

    public GaussianProcessModel setOptimizer(
        @org.jpmml.model.annotations.Property("optimizer")
        String optimizer) {
        this.optimizer = optimizer;
        return this;
    }

    @Override
    public boolean isScorable() {
        if (scorable == null) {
            return DEFAULT_SCORABLE;
        } else {
            return scorable;
        }
    }

    @Override
    public GaussianProcessModel setScorable(
        @org.jpmml.model.annotations.Property("scorable")
        Boolean scorable) {
        this.scorable = scorable;
        return this;
    }

    @Override
    public MathContext getMathContext() {
        if (mathContext == null) {
            return MathContext.DOUBLE;
        } else {
            return mathContext;
        }
    }

    @Override
    public GaussianProcessModel setMathContext(
        @org.jpmml.model.annotations.Property("mathContext")
        MathContext mathContext) {
        this.mathContext = mathContext;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public GaussianProcessModel addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public MiningSchema requireMiningSchema() {
        if (this.miningSchema == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_MININGSCHEMA);
        }
        return this.miningSchema;
    }

    @Override
    public MiningSchema getMiningSchema() {
        return miningSchema;
    }

    @Override
    public GaussianProcessModel setMiningSchema(
        @org.jpmml.model.annotations.Property("miningSchema")
        MiningSchema miningSchema) {
        this.miningSchema = miningSchema;
        return this;
    }

    @Override
    public Output getOutput() {
        return output;
    }

    @Override
    public GaussianProcessModel setOutput(
        @org.jpmml.model.annotations.Property("output")
        Output output) {
        this.output = output;
        return this;
    }

    @Override
    public ModelStats getModelStats() {
        return modelStats;
    }

    @Override
    public GaussianProcessModel setModelStats(
        @org.jpmml.model.annotations.Property("modelStats")
        ModelStats modelStats) {
        this.modelStats = modelStats;
        return this;
    }

    @Override
    public ModelExplanation getModelExplanation() {
        return modelExplanation;
    }

    @Override
    public GaussianProcessModel setModelExplanation(
        @org.jpmml.model.annotations.Property("modelExplanation")
        ModelExplanation modelExplanation) {
        this.modelExplanation = modelExplanation;
        return this;
    }

    @Override
    public Targets getTargets() {
        return targets;
    }

    @Override
    public GaussianProcessModel setTargets(
        @org.jpmml.model.annotations.Property("targets")
        Targets targets) {
        this.targets = targets;
        return this;
    }

    @Override
    public LocalTransformations getLocalTransformations() {
        return localTransformations;
    }

    @Override
    public GaussianProcessModel setLocalTransformations(
        @org.jpmml.model.annotations.Property("localTransformations")
        LocalTransformations localTransformations) {
        this.localTransformations = localTransformations;
        return this;
    }

    public RadialBasisKernel requireRadialBasisKernel() {
        if (this.radialBasisKernel == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_RADIALBASISKERNEL);
        }
        return this.radialBasisKernel;
    }

    public RadialBasisKernel getRadialBasisKernel() {
        return radialBasisKernel;
    }

    public GaussianProcessModel setRadialBasisKernel(
        @org.jpmml.model.annotations.Property("radialBasisKernel")
        RadialBasisKernel radialBasisKernel) {
        this.radialBasisKernel = radialBasisKernel;
        return this;
    }

    public ARDSquaredExponentialKernel requireARDSquaredExponentialKernel() {
        if (this.ardSquaredExponentialKernel == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_ARDSQUAREDEXPONENTIALKERNEL);
        }
        return this.ardSquaredExponentialKernel;
    }

    public ARDSquaredExponentialKernel getARDSquaredExponentialKernel() {
        return ardSquaredExponentialKernel;
    }

    public GaussianProcessModel setARDSquaredExponentialKernel(
        @org.jpmml.model.annotations.Property("ardSquaredExponentialKernel")
        ARDSquaredExponentialKernel ardSquaredExponentialKernel) {
        this.ardSquaredExponentialKernel = ardSquaredExponentialKernel;
        return this;
    }

    public AbsoluteExponentialKernel requireAbsoluteExponentialKernel() {
        if (this.absoluteExponentialKernel == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_ABSOLUTEEXPONENTIALKERNEL);
        }
        return this.absoluteExponentialKernel;
    }

    public AbsoluteExponentialKernel getAbsoluteExponentialKernel() {
        return absoluteExponentialKernel;
    }

    public GaussianProcessModel setAbsoluteExponentialKernel(
        @org.jpmml.model.annotations.Property("absoluteExponentialKernel")
        AbsoluteExponentialKernel absoluteExponentialKernel) {
        this.absoluteExponentialKernel = absoluteExponentialKernel;
        return this;
    }

    public GeneralizedExponentialKernel requireGeneralizedExponentialKernel() {
        if (this.generalizedExponentialKernel == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_GENERALIZEDEXPONENTIALKERNEL);
        }
        return this.generalizedExponentialKernel;
    }

    public GeneralizedExponentialKernel getGeneralizedExponentialKernel() {
        return generalizedExponentialKernel;
    }

    public GaussianProcessModel setGeneralizedExponentialKernel(
        @org.jpmml.model.annotations.Property("generalizedExponentialKernel")
        GeneralizedExponentialKernel generalizedExponentialKernel) {
        this.generalizedExponentialKernel = generalizedExponentialKernel;
        return this;
    }

    public TrainingInstances requireTrainingInstances() {
        if (this.trainingInstances == null) {
            throw new MissingElementException(this, PMMLElements.GAUSSIANPROCESSMODEL_TRAININGINSTANCES);
        }
        return this.trainingInstances;
    }

    public TrainingInstances getTrainingInstances() {
        return trainingInstances;
    }

    public GaussianProcessModel setTrainingInstances(
        @org.jpmml.model.annotations.Property("trainingInstances")
        TrainingInstances trainingInstances) {
        this.trainingInstances = trainingInstances;
        return this;
    }

    @Override
    public ModelVerification getModelVerification() {
        return modelVerification;
    }

    @Override
    public GaussianProcessModel setModelVerification(
        @org.jpmml.model.annotations.Property("modelVerification")
        ModelVerification modelVerification) {
        this.modelVerification = modelVerification;
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = PMMLObject.traverse(visitor, getExtensions());
            }
            if (status == VisitorAction.CONTINUE) {
                status = PMMLObject.traverse(visitor, getMiningSchema(), getOutput(), getModelStats(), getModelExplanation(), getTargets(), getLocalTransformations(), getRadialBasisKernel(), getARDSquaredExponentialKernel(), getAbsoluteExponentialKernel(), getGeneralizedExponentialKernel(), getTrainingInstances(), getModelVerification());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
